@@ -12,6 +12,14 @@
         <source>Current theme: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Use custom (fast) window transitions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Setting up window transitions</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Export theme</source>
         <translation>Exporter le thème</translation>
